@@ -17,6 +17,9 @@
 #Extraction des options de la ligne de commande
 """Options de la ligne de commande"""
 
+#==============================================================================
+# Imports standards
+#==============================================================================
 from os.path import exists, abspath, isdir, isfile, expanduser
 from optparse import OptionParser
 import sys
@@ -25,8 +28,8 @@ class Options:
     """Extrait les options de la ligne de commande"""
 
     def __init__(self):
-        self.options = ()
-        parser = OptionParser(version="%prog 0.7")
+        self._options = ()
+        parser = OptionParser(version="%prog 0.8")
         self.definit_options(parser)
         self.teste_options()
 
@@ -44,12 +47,12 @@ class Options:
             action="store", type="int", default=2,
             help=u"en secondes pour exécuter une commande du script",
             metavar=u"DÉLAI")
-        self.options = parser.parse_args()
+        self._options = parser.parse_args()
 
     def teste_options(self):
         """Teste les options"""
-        if self.options[0].nomfichier is not None:
-            fichierentree = abspath(expanduser(self.options[0].nomfichier))
+        if self._options[0].nomfichier is not None:
+            fichierentree = abspath(expanduser(self._options[0].nomfichier))
             if not exists(fichierentree):
                 print "Le fichier %s n'existe pas." % fichierentree
                 sys.exit(1)
@@ -57,10 +60,10 @@ class Options:
                 print "%s n'est pas un fichier." % fichierentree
                 sys.exit(1)
             else:
-                self.options[0].nomfichier = fichierentree
+                self._options[0].nomfichier = fichierentree
 
-        if self.options[0].repsortie is not None:
-            repertoiresortie = abspath(expanduser(self.options[0].repsortie))
+        if self._options[0].repsortie is not None:
+            repertoiresortie = abspath(expanduser(self._options[0].repsortie))
             if not exists(repertoiresortie):
                 print "Le répertoire %s n'existe pas." % repertoiresortie
                 sys.exit(1)
@@ -68,15 +71,16 @@ class Options:
                 print "%s n'est pas un répertoire." % repertoiresortie
                 sys.exit(1)
             else:
-                self.options[0].repsortie = repertoiresortie    
+                self._options[0].repsortie = repertoiresortie    
 
-        if self.options[0].delai is not None:
-            if self.options[0].delai < -1 or self.options[0].delai > sys.maxint:
+        if self._options[0].delai is not None:
+            if self._options[0].delai < -1 or \
+				self._options[0].delai > sys.maxint:
                 print "La valeur indiqué n'est pas valide.\nLa valeur délai \
 doit être >= -1 et <= valeur d'un entier sur votre système."
                 sys.exit(1)
             
     def lesoptions(self):
         """Retourne les options de la ligne de commande"""
-        return self.options
+        return self._options
 
